/*******************************************************************************
* File Name: BlueTooth_PM.c
* Version 2.30
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "BlueTooth.h"


/***************************************
* Local data allocation
***************************************/

static BlueTooth_BACKUP_STRUCT  BlueTooth_backup =
{
    /* enableState - disabled */
    0u,
};



/*******************************************************************************
* Function Name: BlueTooth_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  BlueTooth_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void BlueTooth_SaveConfig(void)
{
    #if (CY_UDB_V0)

        #if(BlueTooth_CONTROL_REG_REMOVED == 0u)
            BlueTooth_backup.cr = BlueTooth_CONTROL_REG;
        #endif /* End BlueTooth_CONTROL_REG_REMOVED */

        #if( (BlueTooth_RX_ENABLED) || (BlueTooth_HD_ENABLED) )
            BlueTooth_backup.rx_period = BlueTooth_RXBITCTR_PERIOD_REG;
            BlueTooth_backup.rx_mask = BlueTooth_RXSTATUS_MASK_REG;
            #if (BlueTooth_RXHW_ADDRESS_ENABLED)
                BlueTooth_backup.rx_addr1 = BlueTooth_RXADDRESS1_REG;
                BlueTooth_backup.rx_addr2 = BlueTooth_RXADDRESS2_REG;
            #endif /* End BlueTooth_RXHW_ADDRESS_ENABLED */
        #endif /* End BlueTooth_RX_ENABLED | BlueTooth_HD_ENABLED*/

        #if(BlueTooth_TX_ENABLED)
            #if(BlueTooth_TXCLKGEN_DP)
                BlueTooth_backup.tx_clk_ctr = BlueTooth_TXBITCLKGEN_CTR_REG;
                BlueTooth_backup.tx_clk_compl = BlueTooth_TXBITCLKTX_COMPLETE_REG;
            #else
                BlueTooth_backup.tx_period = BlueTooth_TXBITCTR_PERIOD_REG;
            #endif /*End BlueTooth_TXCLKGEN_DP */
            BlueTooth_backup.tx_mask = BlueTooth_TXSTATUS_MASK_REG;
        #endif /*End BlueTooth_TX_ENABLED */


    #else /* CY_UDB_V1 */

        #if(BlueTooth_CONTROL_REG_REMOVED == 0u)
            BlueTooth_backup.cr = BlueTooth_CONTROL_REG;
        #endif /* End BlueTooth_CONTROL_REG_REMOVED */

    #endif  /* End CY_UDB_V0 */
}


/*******************************************************************************
* Function Name: BlueTooth_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  BlueTooth_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void BlueTooth_RestoreConfig(void)
{

    #if (CY_UDB_V0)

        #if(BlueTooth_CONTROL_REG_REMOVED == 0u)
            BlueTooth_CONTROL_REG = BlueTooth_backup.cr;
        #endif /* End BlueTooth_CONTROL_REG_REMOVED */

        #if( (BlueTooth_RX_ENABLED) || (BlueTooth_HD_ENABLED) )
            BlueTooth_RXBITCTR_PERIOD_REG = BlueTooth_backup.rx_period;
            BlueTooth_RXSTATUS_MASK_REG = BlueTooth_backup.rx_mask;
            #if (BlueTooth_RXHW_ADDRESS_ENABLED)
                BlueTooth_RXADDRESS1_REG = BlueTooth_backup.rx_addr1;
                BlueTooth_RXADDRESS2_REG = BlueTooth_backup.rx_addr2;
            #endif /* End BlueTooth_RXHW_ADDRESS_ENABLED */
        #endif  /* End (BlueTooth_RX_ENABLED) || (BlueTooth_HD_ENABLED) */

        #if(BlueTooth_TX_ENABLED)
            #if(BlueTooth_TXCLKGEN_DP)
                BlueTooth_TXBITCLKGEN_CTR_REG = BlueTooth_backup.tx_clk_ctr;
                BlueTooth_TXBITCLKTX_COMPLETE_REG = BlueTooth_backup.tx_clk_compl;
            #else
                BlueTooth_TXBITCTR_PERIOD_REG = BlueTooth_backup.tx_period;
            #endif /*End BlueTooth_TXCLKGEN_DP */
            BlueTooth_TXSTATUS_MASK_REG = BlueTooth_backup.tx_mask;
        #endif /*End BlueTooth_TX_ENABLED */

    #else /* CY_UDB_V1 */

        #if(BlueTooth_CONTROL_REG_REMOVED == 0u)
            BlueTooth_CONTROL_REG = BlueTooth_backup.cr;
        #endif /* End BlueTooth_CONTROL_REG_REMOVED */

    #endif  /* End CY_UDB_V0 */
}


/*******************************************************************************
* Function Name: BlueTooth_Sleep
********************************************************************************
*
* Summary:
*  Stops and saves the user configuration. Should be called
*  just prior to entering sleep.
*
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  BlueTooth_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void BlueTooth_Sleep(void)
{

    #if(BlueTooth_RX_ENABLED || BlueTooth_HD_ENABLED)
        if((BlueTooth_RXSTATUS_ACTL_REG  & BlueTooth_INT_ENABLE) != 0u)
        {
            BlueTooth_backup.enableState = 1u;
        }
        else
        {
            BlueTooth_backup.enableState = 0u;
        }
    #else
        if((BlueTooth_TXSTATUS_ACTL_REG  & BlueTooth_INT_ENABLE) !=0u)
        {
            BlueTooth_backup.enableState = 1u;
        }
        else
        {
            BlueTooth_backup.enableState = 0u;
        }
    #endif /* End BlueTooth_RX_ENABLED || BlueTooth_HD_ENABLED*/

    BlueTooth_Stop();
    BlueTooth_SaveConfig();
}


/*******************************************************************************
* Function Name: BlueTooth_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  BlueTooth_backup - used when non-retention registers are restored.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void BlueTooth_Wakeup(void)
{
    BlueTooth_RestoreConfig();
    #if( (BlueTooth_RX_ENABLED) || (BlueTooth_HD_ENABLED) )
        BlueTooth_ClearRxBuffer();
    #endif /* End (BlueTooth_RX_ENABLED) || (BlueTooth_HD_ENABLED) */
    #if(BlueTooth_TX_ENABLED || BlueTooth_HD_ENABLED)
        BlueTooth_ClearTxBuffer();
    #endif /* End BlueTooth_TX_ENABLED || BlueTooth_HD_ENABLED */

    if(BlueTooth_backup.enableState != 0u)
    {
        BlueTooth_Enable();
    }
}


/* [] END OF FILE */
