/*******************************************************************************
* File Name: ClockTimer.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_ClockTimer_H)
#define CY_CLOCK_ClockTimer_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_20 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void ClockTimer_Start(void) ;
void ClockTimer_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void ClockTimer_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void ClockTimer_StandbyPower(uint8 state) ;
void ClockTimer_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 ClockTimer_GetDividerRegister(void) ;
void ClockTimer_SetModeRegister(uint8 modeBitMask) ;
void ClockTimer_ClearModeRegister(uint8 modeBitMask) ;
uint8 ClockTimer_GetModeRegister(void) ;
void ClockTimer_SetSourceRegister(uint8 clkSource) ;
uint8 ClockTimer_GetSourceRegister(void) ;
#if defined(ClockTimer__CFG3)
void ClockTimer_SetPhaseRegister(uint8 clkPhase) ;
uint8 ClockTimer_GetPhaseRegister(void) ;
#endif /* defined(ClockTimer__CFG3) */

#define ClockTimer_Enable()                       ClockTimer_Start()
#define ClockTimer_Disable()                      ClockTimer_Stop()
#define ClockTimer_SetDivider(clkDivider)         ClockTimer_SetDividerRegister(clkDivider, 1u)
#define ClockTimer_SetDividerValue(clkDivider)    ClockTimer_SetDividerRegister((clkDivider) - 1u, 1u)
#define ClockTimer_SetMode(clkMode)               ClockTimer_SetModeRegister(clkMode)
#define ClockTimer_SetSource(clkSource)           ClockTimer_SetSourceRegister(clkSource)
#if defined(ClockTimer__CFG3)
#define ClockTimer_SetPhase(clkPhase)             ClockTimer_SetPhaseRegister(clkPhase)
#define ClockTimer_SetPhaseValue(clkPhase)        ClockTimer_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(ClockTimer__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define ClockTimer_CLKEN              (* (reg8 *) ClockTimer__PM_ACT_CFG)
#define ClockTimer_CLKEN_PTR          ((reg8 *) ClockTimer__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define ClockTimer_CLKSTBY            (* (reg8 *) ClockTimer__PM_STBY_CFG)
#define ClockTimer_CLKSTBY_PTR        ((reg8 *) ClockTimer__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define ClockTimer_DIV_LSB            (* (reg8 *) ClockTimer__CFG0)
#define ClockTimer_DIV_LSB_PTR        ((reg8 *) ClockTimer__CFG0)
#define ClockTimer_DIV_PTR            ((reg16 *) ClockTimer__CFG0)

/* Clock MSB divider configuration register. */
#define ClockTimer_DIV_MSB            (* (reg8 *) ClockTimer__CFG1)
#define ClockTimer_DIV_MSB_PTR        ((reg8 *) ClockTimer__CFG1)

/* Mode and source configuration register */
#define ClockTimer_MOD_SRC            (* (reg8 *) ClockTimer__CFG2)
#define ClockTimer_MOD_SRC_PTR        ((reg8 *) ClockTimer__CFG2)

#if defined(ClockTimer__CFG3)
/* Analog clock phase configuration register */
#define ClockTimer_PHASE              (* (reg8 *) ClockTimer__CFG3)
#define ClockTimer_PHASE_PTR          ((reg8 *) ClockTimer__CFG3)
#endif /* defined(ClockTimer__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define ClockTimer_CLKEN_MASK         ClockTimer__PM_ACT_MSK
#define ClockTimer_CLKSTBY_MASK       ClockTimer__PM_STBY_MSK

/* CFG2 field masks */
#define ClockTimer_SRC_SEL_MSK        ClockTimer__CFG2_SRC_SEL_MASK
#define ClockTimer_MODE_MASK          (~(ClockTimer_SRC_SEL_MSK))

#if defined(ClockTimer__CFG3)
/* CFG3 phase mask */
#define ClockTimer_PHASE_MASK         ClockTimer__CFG3_PHASE_DLY_MASK
#endif /* defined(ClockTimer__CFG3) */

#endif /* CY_CLOCK_ClockTimer_H */


/* [] END OF FILE */
