/*******************************************************************************
* File Name: ENCG_20.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "ENCG_20.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 ENCG_20__PORT == 15 && ((ENCG_20__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: ENCG_20_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void ENCG_20_Write(uint8 value) 
{
    uint8 staticBits = (ENCG_20_DR & (uint8)(~ENCG_20_MASK));
    ENCG_20_DR = staticBits | ((uint8)(value << ENCG_20_SHIFT) & ENCG_20_MASK);
}


/*******************************************************************************
* Function Name: ENCG_20_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  ENCG_20_DM_STRONG     Strong Drive 
*  ENCG_20_DM_OD_HI      Open Drain, Drives High 
*  ENCG_20_DM_OD_LO      Open Drain, Drives Low 
*  ENCG_20_DM_RES_UP     Resistive Pull Up 
*  ENCG_20_DM_RES_DWN    Resistive Pull Down 
*  ENCG_20_DM_RES_UPDWN  Resistive Pull Up/Down 
*  ENCG_20_DM_DIG_HIZ    High Impedance Digital 
*  ENCG_20_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void ENCG_20_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(ENCG_20_0, mode);
}


/*******************************************************************************
* Function Name: ENCG_20_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro ENCG_20_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 ENCG_20_Read(void) 
{
    return (ENCG_20_PS & ENCG_20_MASK) >> ENCG_20_SHIFT;
}


/*******************************************************************************
* Function Name: ENCG_20_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 ENCG_20_ReadDataReg(void) 
{
    return (ENCG_20_DR & ENCG_20_MASK) >> ENCG_20_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(ENCG_20_INTSTAT) 

    /*******************************************************************************
    * Function Name: ENCG_20_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 ENCG_20_ClearInterrupt(void) 
    {
        return (ENCG_20_INTSTAT & ENCG_20_MASK) >> ENCG_20_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
